==> victory-pie-1.0.0.jar: META-INF/resources/webjars/victory-pie/1.0.0/lib/components/slice-label.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _radium = require("radium");

var _radium2 = _interopRequireDefault(_radium);

var _victoryUtil = require("victory-util");

var _lodashObjectMerge = require("lodash/object/merge");

var _lodashObjectMerge2 = _interopRequireDefault(_lodashObjectMerge);

var _lodashObjectAssign = require("lodash/object/assign");

var _lodashObjectAssign2 = _interopRequireDefault(_lodashObjectAssign);

var _victoryLabel = require("victory-label");

var SliceLabel = (function (_React$Component) {
  _inherits(SliceLabel, _React$Component);

  function SliceLabel() {
    _classCallCheck(this, _SliceLabel);

    _get(Object.getPrototypeOf(_SliceLabel.prototype), "constructor", this).apply(this, arguments);
  }

  _createClass(SliceLabel, [{
    key: "renderLabelComponent",
    value: function renderLabelComponent(props, position, label) {
      var component = props.labelComponent;
      var style = _victoryUtil.Chart.evaluateStyle((0, _lodashObjectMerge2["default"])({ padding: 0 }, props.style, component.props.style), this.data);
      var children = component.props.children || label;
      var newProps = {
        x: component.props.x || position[0],
        y: component.props.y || position[1],
        data: props.slice.data, // Pass data for custom label component to access
        textAnchor: component.props.textAnchor || "start",
        verticalAnchor: component.props.verticalAnchor || "middle",
        style: style
      };
      return _react2["default"].cloneElement(component, newProps, children);
    }
  }, {
    key: "renderVictoryLabel",
    value: function renderVictoryLabel(props, position, label) {
      var style = _victoryUtil.Chart.evaluateStyle((0, _lodashObjectAssign2["default"])({ padding: 0 }, props.style), props.slice.data);
      return _react2["default"].createElement(
        _victoryLabel.VictoryLabel,
        {
          x: position[0],
          y: position[1],
          data: props.slice.data,
          style: style
        },
        label
      );
    }
  }, {
    key: "renderLabel",
    value: function renderLabel(props) {
      var position = props.positionFunction(props.slice);
      var data = props.slice.data;
      var dataLabel = data.xName ? "" + data.xName : "" + data.x;
      var label = data.label ? "" + _victoryUtil.Chart.evaluateProp(data.label, data) : dataLabel;
      return props.labelComponent ? this.renderLabelComponent(props, position, label) : this.renderVictoryLabel(props, position, label);
    }
  }, {
    key: "render",
    value: function render() {
      return this.renderLabel(this.props);
    }
  }], [{
    key: "propTypes",
    value: {
      labelComponent: _react.PropTypes.any,
      positionFunction: _react.PropTypes.func,
      slice: _react.PropTypes.object,
      style: _react.PropTypes.object
    },
    enumerable: true
  }]);

  var _SliceLabel = SliceLabel;
  SliceLabel = (0, _radium2["default"])(SliceLabel) || SliceLabel;
  return SliceLabel;
})(_react2["default"].Component);

exports["default"] = SliceLabel;
module.exports = exports["default"];

==> victory-pie-1.0.1.jar: META-INF/resources/webjars/victory-pie/1.0.1/lib/components/slice-label.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ("value" in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _radium = require("radium");

var _radium2 = _interopRequireDefault(_radium);

var _victoryUtil = require("victory-util");

var _lodashObjectMerge = require("lodash/object/merge");

var _lodashObjectMerge2 = _interopRequireDefault(_lodashObjectMerge);

var _lodashObjectAssign = require("lodash/object/assign");

var _lodashObjectAssign2 = _interopRequireDefault(_lodashObjectAssign);

var _victoryLabel = require("victory-label");

var SliceLabel = (function (_React$Component) {
  _inherits(SliceLabel, _React$Component);

  function SliceLabel() {
    _classCallCheck(this, _SliceLabel);

    _get(Object.getPrototypeOf(_SliceLabel.prototype), "constructor", this).apply(this, arguments);
  }

  _createClass(SliceLabel, [{
    key: "renderLabelComponent",
    value: function renderLabelComponent(props, position, label) {
      var component = props.labelComponent;
      var style = _victoryUtil.Helpers.evaluateStyle((0, _lodashObjectMerge2["default"])({ padding: 0 }, props.style, component.props.style), this.data);
      var children = component.props.children || label;
      var newProps = {
        x: component.props.x || position[0],
        y: component.props.y || position[1],
        data: props.slice.data, // Pass data for custom label component to access
        textAnchor: component.props.textAnchor || "start",
        verticalAnchor: component.props.verticalAnchor || "middle",
        style: style
      };
      return _react2["default"].cloneElement(component, newProps, children);
    }
  }, {
    key: "renderVictoryLabel",
    value: function renderVictoryLabel(props, position, label) {
      var style = _victoryUtil.Helpers.evaluateStyle((0, _lodashObjectAssign2["default"])({ padding: 0 }, props.style), props.slice.data);
      return _react2["default"].createElement(
        _victoryLabel.VictoryLabel,
        {
          x: position[0],
          y: position[1],
          data: props.slice.data,
          style: style
        },
        label
      );
    }
  }, {
    key: "renderLabel",
    value: function renderLabel(props) {
      var position = props.positionFunction(props.slice);
      var data = props.slice.data;
      var dataLabel = data.xName ? "" + data.xName : "" + data.x;
      var label = data.label ? "" + _victoryUtil.Helpers.evaluateProp(data.label, data) : dataLabel;
      return props.labelComponent ? this.renderLabelComponent(props, position, label) : this.renderVictoryLabel(props, position, label);
    }
  }, {
    key: "render",
    value: function render() {
      return this.renderLabel(this.props);
    }
  }], [{
    key: "propTypes",
    value: {
      labelComponent: _react.PropTypes.any,
      positionFunction: _react.PropTypes.func,
      slice: _react.PropTypes.object,
      style: _react.PropTypes.object
    },
    enumerable: true
  }]);

  var _SliceLabel = SliceLabel;
  SliceLabel = (0, _radium2["default"])(SliceLabel) || SliceLabel;
  return SliceLabel;
})(_react2["default"].Component);

exports["default"] = SliceLabel;
module.exports = exports["default"];
